==> jc-1.4.0.tar.gz: javax/swing/UIDefaults__24ProxyLazyValue.h <==
// public class javax.swing.UIDefaults$ProxyLazyValue

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e9839eba79494131 javax_swing_UIDefaults__24ProxyLazyValue

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIDefaults__24ProxyLazyValue_H_
#define _JC_javax_swing_UIDefaults__24ProxyLazyValue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_UIDefaults$object;
struct _jc_javax_swing_UIDefaults__24LazyValue$object;

// Typedefs
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue$refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue$nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object	_jc_javax_swing_UIDefaults__24ProxyLazyValue$object;

typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vmethods	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vmethods;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtable	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vtable;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype;

// Constructors
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue$method$_init$2c5e5390a6534277(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue$method$_init$1673a34f53b5c3b8(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_UIDefaults__24ProxyLazyValue$method$createValue$5246839c46d82ae8(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_javax_swing_UIDefaults$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIDefaults__24ProxyLazyValue$method_info$createValue$5246839c46d82ae8;

// Virtual methods structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vmethods {
	struct _jc_java_lang_Object$object	*(*createValue$5246839c46d82ae8)(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_javax_swing_UIDefaults$object *);
};

// Vtable
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vmethods	javax_swing_UIDefaults__24ProxyLazyValue;
};

// Vtype
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype {
	_jc_type			type;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_refs {
	struct _jc_object	*inner;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$refs {
    _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_refs	javax_swing_UIDefaults__24ProxyLazyValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_nonrefs	javax_swing_UIDefaults__24ProxyLazyValue;
};

// Object instance structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object {
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype	*vtype;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype _jc_javax_swing_UIDefaults__24ProxyLazyValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIDefaults__24ProxyLazyValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIDefaults__24ProxyLazyValue$class_object;

#endif	/* _JC_javax_swing_UIDefaults__24ProxyLazyValue_H_ */

==> jc-1.4.5.tar.gz: javax/swing/UIDefaults__24ProxyLazyValue.h <==
// public class javax.swing.UIDefaults$ProxyLazyValue

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 52c3faddeb74d54 javax_swing_UIDefaults__24ProxyLazyValue

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIDefaults__24ProxyLazyValue_H_
#define _JC_javax_swing_UIDefaults__24ProxyLazyValue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_UIDefaults$object;
struct _jc_javax_swing_UIDefaults__24LazyValue$object;

// Typedefs
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue$refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue$nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object	_jc_javax_swing_UIDefaults__24ProxyLazyValue$object;

typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vmethods	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vmethods;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtable	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vtable;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype;

// Constructors
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue$method$_init$2c5e5390a6534277(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue$method$_init$1673a34f53b5c3b8(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_UIDefaults__24ProxyLazyValue$method$createValue$5246839c46d82ae8(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIDefaults__24ProxyLazyValue$method_info$createValue$5246839c46d82ae8;

// Virtual methods structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vmethods {
	struct _jc_java_lang_Object$object	*(*createValue$5246839c46d82ae8)(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vmethods	javax_swing_UIDefaults__24ProxyLazyValue;
};

// Vtype
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype {
	_jc_type			type;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_refs {
	struct _jc_object	*inner;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$refs {
    _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_refs	javax_swing_UIDefaults__24ProxyLazyValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIDefaults__24ProxyLazyValue$sub_nonrefs	javax_swing_UIDefaults__24ProxyLazyValue;
};

// Object instance structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object {
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype	*vtype;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIDefaults__24ProxyLazyValue$vtype _jc_javax_swing_UIDefaults__24ProxyLazyValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIDefaults__24ProxyLazyValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIDefaults__24ProxyLazyValue$class_object;

#endif	/* _JC_javax_swing_UIDefaults__24ProxyLazyValue_H_ */
